Contributing
============

We welcome all bug reports and feature suggestions to pysmo. Please submit these on our
`GitHub issue page <https://github.com/pysmo/pysmo/issues/new>`_. If you are submitting 
a bug report, please also include information about your environment (operating system,
Python version etc.).

If you are also able to contribute code we will be even more delighted! Please keep the
following in mind when submitting a pull request on GitHub:

   - Adhere to the `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_ style guide.
   - If applicable, provide a test script using `pytest <https://docs.pytest.org/en/latest/>`_
     or the built in `unittest <https://docs.python.org/3/library/unittest.html>`_ module.
   - Provide docstrings inside your Python code that can be used for this documentation.
     Please also provide references if applicable.
